[![Code Health](https://landscape.io/github/Nikea/xray-vision/master/landscape.svg?style=flat)](https://landscape.io/github/Nikea/xray-vision/master)


xray-vision
===========

Domain specific plotting and GUI widgets for X-ray science

## Conda Recipes

Install the most recent tagged build: `conda install xray-vision -c lightsource2-tag`

Install the most recent tagged build: `conda install xray-vision -c lightsource2-dev`

Find the tagged recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-tag/xray-vision) and the dev recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-dev/xray-vision)
